@@ -58,7 +58,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListJobRunsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
     """
 
@@ -66,21 +66,21 @@ class ListJobRunsPaginator(Boto3Paginator):
         self,
         *,
         virtualClusterId: str,
-        createdBefore: Union[datetime, str] = None,
-        createdAfter: Union[datetime, str] = None,
-        name: str = None,
-        states: Sequence[JobRunStateType] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        createdBefore: Union[datetime, str] = ...,
+        createdAfter: Union[datetime, str] = ...,
+        name: str = ...,
+        states: Sequence[JobRunStateType] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListJobRunsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
 
 class ListManagedEndpointsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
     """
 
@@ -88,35 +88,35 @@ class ListManagedEndpointsPaginator(Boto3Paginator):
         self,
         *,
         virtualClusterId: str,
-        createdBefore: Union[datetime, str] = None,
-        createdAfter: Union[datetime, str] = None,
-        types: Sequence[str] = None,
-        states: Sequence[EndpointStateType] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        createdBefore: Union[datetime, str] = ...,
+        createdAfter: Union[datetime, str] = ...,
+        types: Sequence[str] = ...,
+        states: Sequence[EndpointStateType] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListManagedEndpointsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
 
 class ListVirtualClustersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
     """
 
     def paginate(
         self,
         *,
-        containerProviderId: str = None,
-        containerProviderType: Literal["EKS"] = None,
-        createdAfter: Union[datetime, str] = None,
-        createdBefore: Union[datetime, str] = None,
-        states: Sequence[VirtualClusterStateType] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        containerProviderId: str = ...,
+        containerProviderType: Literal["EKS"] = ...,
+        createdAfter: Union[datetime, str] = ...,
+        createdBefore: Union[datetime, str] = ...,
+        states: Sequence[VirtualClusterStateType] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListVirtualClustersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
