@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     EndpointStateType,
@@ -121,7 +121,7 @@ class CloudWatchMonitoringConfigurationTypeDef(
 ConfigurationOverridesTypeDef = TypedDict(
     "ConfigurationOverridesTypeDef",
     {
-        "applicationConfiguration": List["ConfigurationTypeDef"],
+        "applicationConfiguration": Sequence["ConfigurationTypeDef"],
         "monitoringConfiguration": "MonitoringConfigurationTypeDef",
     },
     total=False,
@@ -136,8 +136,8 @@ _RequiredConfigurationTypeDef = TypedDict(
 _OptionalConfigurationTypeDef = TypedDict(
     "_OptionalConfigurationTypeDef",
     {
-        "properties": Dict[str, str],
-        "configurations": List[Dict[str, Any]],
+        "properties": Mapping[str, str],
+        "configurations": Sequence[Dict[str, Any]],
     },
     total=False,
 )
@@ -193,7 +193,7 @@ _OptionalCreateManagedEndpointRequestRequestTypeDef = TypedDict(
     "_OptionalCreateManagedEndpointRequestRequestTypeDef",
     {
         "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -228,7 +228,7 @@ _RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
 _OptionalCreateVirtualClusterRequestRequestTypeDef = TypedDict(
     "_OptionalCreateVirtualClusterRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -405,7 +405,7 @@ _OptionalListJobRunsRequestRequestTypeDef = TypedDict(
         "createdBefore": Union[datetime, str],
         "createdAfter": Union[datetime, str],
         "name": str,
-        "states": List[JobRunStateType],
+        "states": Sequence[JobRunStateType],
         "maxResults": int,
         "nextToken": str,
     },
@@ -439,8 +439,8 @@ _OptionalListManagedEndpointsRequestRequestTypeDef = TypedDict(
     {
         "createdBefore": Union[datetime, str],
         "createdAfter": Union[datetime, str],
-        "types": List[str],
-        "states": List[EndpointStateType],
+        "types": Sequence[str],
+        "states": Sequence[EndpointStateType],
         "maxResults": int,
         "nextToken": str,
     },
@@ -486,7 +486,7 @@ ListVirtualClustersRequestRequestTypeDef = TypedDict(
         "containerProviderType": Literal["EKS"],
         "createdAfter": Union[datetime, str],
         "createdBefore": Union[datetime, str],
-        "states": List[VirtualClusterStateType],
+        "states": Sequence[VirtualClusterStateType],
         "maxResults": int,
         "nextToken": str,
     },
@@ -577,7 +577,7 @@ _OptionalStartJobRunRequestRequestTypeDef = TypedDict(
     {
         "name": str,
         "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -604,7 +604,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -612,7 +612,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
